@@ -38,7 +38,7 @@ _TaskBridge = (
 class FewshotExampleMultiLabel(BaseFewshotExample):
     """Few‑shot example for multi‑label classification with per‑label confidences."""
 
-    reasoning: str
+    reasoning: str = ""
     confidence_per_label: dict[str, float]
 
     @override
@@ -57,7 +57,7 @@ class FewshotExampleMultiLabel(BaseFewshotExample):
 class FewshotExampleSingleLabel(BaseFewshotExample):
     """Few‑shot example for single‑label classification with a global confidence."""
 
-    reasoning: str
+    reasoning: str = ""
     label: str
     confidence: float
 
